@@ -214,7 +214,7 @@ gupnp_simple_igd_thread_dispose (GObject *object)
     {
       GSource *src = g_idle_source_new ();
 
-      g_source_set_callback (src, stop_loop, self, NULL);
+      g_source_set_callback (src, (GSourceFunc) stop_loop, self, NULL);
       g_source_attach (src, self->priv->context);
       g_source_unref (src);
 
@@ -262,6 +262,8 @@ thread_func (gpointer dat)
   struct thread_data *data = dat;
   GMainLoop *loop = g_main_loop_new (data->context, FALSE);
 
+  g_main_context_push_thread_default(data->context);
+
   g_mutex_lock (data->mutex);
   data->loop = loop;
   g_mutex_unlock (data->mutex);
