@@ -147,9 +147,9 @@ static void gupnp_simple_igd_remove_port_real (GUPnPSimpleIgd *self,
     guint external_port);
 
 GQuark
-gupnp_simple_igd_get_error_domain (void)
+gupnp_simple_igd_error_quark (void)
 {
-  return g_quark_from_static_string ("fs-upnp-simple-igd-error");
+  return g_quark_from_static_string ("gupnp-simple-igd-error");
 }
 
 
@@ -184,7 +184,8 @@ gupnp_simple_igd_class_init (GUPnPSimpleIgdClass *klass)
    * @replaces_external_ip: if this mapping replaces another mapping,
    *  this is the old external IP
    * @external_port: the external port that was allocated
-   * @local_ip: internal ip this is forwarded to
+   * @local_ip: IP address that the router should forward the packets to. It
+   *  could be the address of another machine on the local network
    * @local_port: the local port
    * @description: the user's selected description
    *
@@ -616,12 +617,14 @@ _service_proxy_got_external_ip_address (GUPnPServiceProxy *proxy,
       for (i=0; i < prox->proxymappings->len; i++)
       {
         struct ProxyMapping *pm = g_ptr_array_index (prox->proxymappings, i);
+        GError gerror = {GUPNP_SIMPLE_IGD_ERROR,
+                         GUPNP_SIMPLE_IGD_ERROR_EXTERNAL_ADDRESS,
+                         "Invalid IP address returned by router"};
 
         g_signal_emit (self, signals[SIGNAL_ERROR_MAPPING_PORT],
-            GUPNP_SIMPLE_IGD_ERROR, GUPNP_SIMPLE_IGD_ERROR_EXTERNAL_ADDRESS,
-            pm->mapping->protocol, pm->mapping->requested_external_port,
-            pm->mapping->local_ip, pm->mapping->local_port,
-            pm->mapping->description);
+            GUPNP_SIMPLE_IGD_ERROR, &gerror, pm->mapping->protocol,
+            pm->mapping->requested_external_port, pm->mapping->local_ip,
+            pm->mapping->local_port, pm->mapping->description);
       }
       return;
     }
